;************************************************************************
;*																		*
;*	CEREBOT.INC	--	General Cerebot Interface Declarations				*
;*																		*
;************************************************************************
;*	Author:		Gene Apperson											*
;*	Copyright 2005, Digilent Inc.										*
;************************************************************************
;*	Module Description:													*
;*																		*
;*	This header file contains symbol declarations describing ports and	*
;*	pins for access to the on-board i/o devices and interface connector	*
;*	pins on the Cerebot.												*
;*																		*
;************************************************************************
;*	Revision History:													*
;*																		*
;*	03/15/2005(GeneA): created											*
;*	10/18/2005(GeneA): fixed error in servo channel ports				*
;*																		*
;************************************************************************
;
.ifndef	_CEREBOT_INC

.equ	_CEREBOT_INC = 1
;
; ---------------------------------------------------------------
;			ATmega64  Internal Declarations
; ---------------------------------------------------------------
;
; These are declarations for useful symbols missing from the
; standard Atmel AVR chip definitions file
;
; Declare bits in the status register
.equ	bnCF	= 0
.equ	bnZF	= 1
.equ	bnNF	= 2
.equ	bnVF	= 3
.equ	bnSF	= 4
.equ	bnHF	= 5
.equ	bnTF	= 6
.equ	bnIF	= 7

; ---------------------------------------------------------------
;				On-Board I/O Declarations
; ---------------------------------------------------------------

;
; Symbol definitions for access to local LEDs
.equ	prtLed1	= PORTE
.equ	prtLed2 = PORTE
.equ	prtLed3 = PORTE
.equ	prtLed4 = PORTE

.equ	ddrLed1 = DDRE
.equ	ddrLed2 = DDRE
.equ	ddrLed3 = DDRE
.equ	ddrLed4 = DDRE

.equ	bnLed1	= 7
.equ	bnLed2	= 6
.equ	bnLed3	= 5
.equ	bnLed4	= 4

; ---------------------------------------------------------------
;				Interface Connector Declarations
; ---------------------------------------------------------------
;
; Symbol definitions for access to connector JA
.equ	prtJA1	= PORTD
.equ	prtJA2	= PORTB
.equ	prtJA3	= PORTD
.equ	prtJA4	= PORTB

.equ	pinJA1	= PIND
.equ	pinJA2	= PINB
.equ	pinJA3	= PIND
.equ	pinJA4	= PINB

.equ	ddrJA1	= DDRD
.equ	ddrJA2	= DDRB
.equ	ddrJA3	= DDRD
.equ	ddrJA4	= DDRB

.equ	bnJA1	= 7
.equ	bnJA2	= 4
.equ	bnJA3	= 5
.equ	bnJA4	= 7
;
; Symbol definitions for access to connector JB
.equ	prtJB1	= PORTD
.equ	prtJB2	= PORTB
.equ	prtJB3	= PORTD
.equ	prtJB4	= PORTB

.equ	pinJB1	= PIND
.equ	pinJB2	= PINB
.equ	pinJB3	= PIND
.equ	pinJB4	= PINB

.equ	ddrJB1	= DDRD
.equ	ddrJB2	= DDRB
.equ	ddrJB3	= DDRD
.equ	ddrJB4	= DDRB

.equ	bnJB1	= 6
.equ	bnJB2	= 5
.equ	bnJB3	= 4
.equ	bnJB4	= 6
;
; Symbol definitions for access to connector JC
.equ	prtJC1	= PORTE
.equ	prtJC2	= PORTE
.equ	prtJC3	= PORTE
.equ	prtJC4	= PORTE

.equ	pinJC1	= PINE
.equ	pinJC2	= PINE
.equ	pinJC3	= PINE
.equ	pinJC4	= PINE

.equ	ddrJC1	= DDRE
.equ	ddrJC2	= DDRE
.equ	ddrJC3	= DDRE
.equ	ddrJC4	= DDRE

.equ	bnJC1	= 6
.equ	bnJC2	= 4
.equ	bnJC3	= 7
.equ	bnJC4	= 5
;
; Symbol definitions for access to connector JD
.equ	prtJD1	= PORTE
.equ	prtJD2	= PORTE
.equ	prtJD3	= PORTE
.equ	prtJD4	= PORTE

.equ	pinJD1	= PINE
.equ	pinJD2	= PINE
.equ	pinJD3	= PINE
.equ	pinJD4	= PINE

.equ	ddrJD1	= DDRE
.equ	ddrJD2	= DDRE
.equ	ddrJD3	= DDRE
.equ	ddrJD4	= DDRE

.equ	bnJD1	= 2
.equ	bnJD2	= 3
.equ	bnJD3	= 0
.equ	bnJD4	= 1
;
; Symbol definitions for access to connector JE
.equ	prtJE1	= PORTD
.equ	prtJE2	= PORTD
.equ	prtJE3	= PORTD
.equ	prtJE4	= PORTD

.equ	pinJE1	= PIND
.equ	pinJE2	= PIND
.equ	pinJE3	= PIND
.equ	pinJE4	= PIND

.equ	ddrJE1	= DDRD
.equ	ddrJE2	= DDRD
.equ	ddrJE3	= DDRD
.equ	ddrJE4	= DDRD

.equ	bnJE1	= 0
.equ	bnJE2	= 1
.equ	bnJE3	= 2
.equ	bnJE4	= 3
;
; Symbol definitions for access to connector JF
.equ	prtJF1	= PORTF
.equ	prtJF2	= PORTF
.equ	prtJF3	= PORTF
.equ	prtJF4	= PORTF

.equ	pinJF1	= PINF
.equ	pinJF2	= PINF
.equ	pinJF3	= PINF
.equ	pinJF4	= PINF

.equ	ddrJF1	= DDRF
.equ	ddrJF2	= DDRF
.equ	ddrJF3	= DDRF
.equ	ddrJF4	= DDRF

.equ	bnJF1	= 0
.equ	bnJF2	= 1
.equ	bnJF3	= 2
.equ	bnJF4	= 3
;
; Symbol definitions for access to connector JG
.equ	prtJG1	= PORTF
.equ	prtJG2	= PORTF
.equ	prtJG3	= PORTF
.equ	prtJG4	= PORTF

.equ	pinJG1	= PINF
.equ	pinJG2	= PINF
.equ	pinJG3	= PINF
.equ	pinJG4	= PINF

.equ	ddrJG1	= DDRF
.equ	ddrJG2	= DDRF
.equ	ddrJG3	= DDRF
.equ	ddrJG4	= DDRF

.equ	bnJG1	= 5
.equ	bnJG2	= 7
.equ	bnJG3	= 6
.equ	bnJG4	= 4

; ---------------------------------------------------------------
;			Symbol Definitions for Servo Connectors
; ---------------------------------------------------------------
;
.equ	prtServo0 = PORTD
.equ	prtServo1 = PORTD
.equ	prtServo2 = PORTD
.equ	prtServo3 = PORTD
.equ	prtServo4 = PORTD
.equ	prtServo5 = PORTB
.equ	prtServo6 = PORTD
.equ	prtServo7 = PORTB

.equ	ddrServo0 = DDRD
.equ	ddrServo1 = DDRD
.equ	ddrServo2 = DDRD
.equ	ddrServo3 = DDRD
.equ	ddrServo4 = DDRD
.equ	ddrServo5 = DDRB
.equ	ddrServo6 = DDRD
.equ	ddrServo7 = DDRB

.equ	bnServo0  = 0
.equ	bnServo1  = 1
.equ	bnServo2  = 2
.equ	bnServo3  = 3
.equ	bnServo4  = 6
.equ	bnServo5  = 5
.equ	bnServo6  = 4
.equ	bnServo7  = 6

; ---------------------------------------------------------------

.endif
;
;************************************************************************
